# torskel
**Python package with skeleton of the base Tornado application.**

Contains basic functions for logging, asynchronous redis, asynchronous http request
from out of box

***Only Python 3.7+***

For redis support  - you need install aioredis >=1.0.0

For CurlAsyncHTTPClient support - you need install pycurl

For MongoDB support - you need install motor

For more information see examples

If you have any questions - visit https://gitter.im/torskel

